const Parser = require('../../lib/parser');

describe('DynamoDB Record Parser', () => {

  describe('parseKeys', () => {
    it('should parse "keys"', () => {
      expect(Parser.parseKeys({
        dynamodb: {
          Keys: {
            primary_key: {
              S: '123',
            },
            sort_key: {
              N: 1,
            },
          },
        },
      })).toEqual({
        primary_key: '123',
        sort_key: 1,
      });
    });

    it('should throw error if "keys" is missing', () => {
      expect(() => {
        Parser.parseKeys({
          eventSourceARN: 'arn:aws:s3:eu-west-1:345565672:table/here-is-table-name',
        });
      }).toThrowErrorMatchingSnapshot();
    });
  });

  describe('getDoc', () => {
    it('should parse "NewImage"', () => {
      expect(Parser.getDoc({
        dynamodb: {
          NewImage: {
            primary_key: {
              S: '123',
            },
            sort_key: {
              N: 1,
            },
          },
        },
      })).toEqual({
        primary_key: '123',
        sort_key: 1,
      });
    });

    it('should parse "NewImage" as null is Action is REMOVE', () => {
      expect(Parser.getDoc({}, 'REMOVE')).toEqual(null);
    });

    it('should throw error if "NewImage" is missing', () => {
      expect(() => {
        Parser.getDoc({
          eventSourceARN: 'arn:aws:s3:eu-west-1:345565672:table/here-is-table-name',
        });
      }).toThrowErrorMatchingSnapshot();
    });
  });
});
